# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['JobArgs', 'Job']

@pulumi.input_type
class JobArgs:
    def __init__(__self__, *,
                 execute_mode: pulumi.Input[builtins.str],
                 group_id: pulumi.Input[builtins.str],
                 job_name: pulumi.Input[builtins.str],
                 job_type: pulumi.Input[builtins.str],
                 namespace: pulumi.Input[builtins.str],
                 time_config: pulumi.Input['JobTimeConfigArgs'],
                 attempt_interval: Optional[pulumi.Input[builtins.int]] = None,
                 class_name: Optional[pulumi.Input[builtins.str]] = None,
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 fail_times: Optional[pulumi.Input[builtins.int]] = None,
                 job_monitor_info: Optional[pulumi.Input['JobJobMonitorInfoArgs']] = None,
                 map_task_xattrs: Optional[pulumi.Input['JobMapTaskXattrsArgs']] = None,
                 max_attempt: Optional[pulumi.Input[builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.str]] = None,
                 namespace_source: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 success_notice_enable: Optional[pulumi.Input[builtins.bool]] = None,
                 task_dispatch_mode: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input[builtins.str]] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None,
                 x_attrs: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Job resource.
        :param pulumi.Input[builtins.str] execute_mode: Task execution mode, the possible results are as follows:
        :param pulumi.Input[builtins.str] group_id: The application ID, which is obtained from the **application management** page of the console.
        :param pulumi.Input[builtins.str] job_name: JobName
        :param pulumi.Input[builtins.str] job_type: Job Type
        :param pulumi.Input[builtins.str] namespace: Namespace, which is obtained on the `Namespace` page of the console.
        :param pulumi.Input['JobTimeConfigArgs'] time_config: Time configuration information See `time_config` below.
        :param pulumi.Input[builtins.int] attempt_interval: Error retry interval, unit s, default value 30.
        :param pulumi.Input[builtins.str] class_name: Full path of the task interface class.
               
               This field is available only when your task is of the Java task type.
        :param pulumi.Input[builtins.str] content: The script code of the python, shell, and go task types.
        :param pulumi.Input[builtins.str] description: Task description.
        :param pulumi.Input[builtins.int] fail_times: Number of consecutive failed alarms
        :param pulumi.Input['JobJobMonitorInfoArgs'] job_monitor_info: Task monitoring information See `job_monitor_info` below.
        :param pulumi.Input['JobMapTaskXattrsArgs'] map_task_xattrs: Advanced configuration, limited to parallel computing, memory grid, and grid computing. See `map_task_xattrs` below.
        :param pulumi.Input[builtins.int] max_attempt: The maximum number of error retries, which is set based on business requirements. The default value is 0.
        :param pulumi.Input[builtins.str] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[builtins.str] namespace_source: Special third parties are required.
        :param pulumi.Input[builtins.str] parameters: User-defined parameters, which can be obtained at runtime.
        :param pulumi.Input[builtins.str] status: Task status. The values are as follows:
        :param pulumi.Input[builtins.bool] success_notice_enable: Success Notification Switch
        :param pulumi.Input[builtins.str] task_dispatch_mode: Advanced configuration of parallel grid tasks, push model or pull model
        :param pulumi.Input[builtins.str] template: K8s task type custom task template
        :param pulumi.Input[builtins.str] timezone: Time Zone
        :param pulumi.Input[builtins.str] x_attrs: Task Extension Field
        """
        pulumi.set(__self__, "execute_mode", execute_mode)
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "job_name", job_name)
        pulumi.set(__self__, "job_type", job_type)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "time_config", time_config)
        if attempt_interval is not None:
            pulumi.set(__self__, "attempt_interval", attempt_interval)
        if class_name is not None:
            pulumi.set(__self__, "class_name", class_name)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if fail_times is not None:
            pulumi.set(__self__, "fail_times", fail_times)
        if job_monitor_info is not None:
            pulumi.set(__self__, "job_monitor_info", job_monitor_info)
        if map_task_xattrs is not None:
            pulumi.set(__self__, "map_task_xattrs", map_task_xattrs)
        if max_attempt is not None:
            pulumi.set(__self__, "max_attempt", max_attempt)
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if namespace_source is not None:
            pulumi.set(__self__, "namespace_source", namespace_source)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if success_notice_enable is not None:
            pulumi.set(__self__, "success_notice_enable", success_notice_enable)
        if task_dispatch_mode is not None:
            pulumi.set(__self__, "task_dispatch_mode", task_dispatch_mode)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)
        if x_attrs is not None:
            pulumi.set(__self__, "x_attrs", x_attrs)

    @property
    @pulumi.getter(name="executeMode")
    def execute_mode(self) -> pulumi.Input[builtins.str]:
        """
        Task execution mode, the possible results are as follows:
        """
        return pulumi.get(self, "execute_mode")

    @execute_mode.setter
    def execute_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "execute_mode", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[builtins.str]:
        """
        The application ID, which is obtained from the **application management** page of the console.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Input[builtins.str]:
        """
        JobName
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter(name="jobType")
    def job_type(self) -> pulumi.Input[builtins.str]:
        """
        Job Type
        """
        return pulumi.get(self, "job_type")

    @job_type.setter
    def job_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "job_type", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[builtins.str]:
        """
        Namespace, which is obtained on the `Namespace` page of the console.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="timeConfig")
    def time_config(self) -> pulumi.Input['JobTimeConfigArgs']:
        """
        Time configuration information See `time_config` below.
        """
        return pulumi.get(self, "time_config")

    @time_config.setter
    def time_config(self, value: pulumi.Input['JobTimeConfigArgs']):
        pulumi.set(self, "time_config", value)

    @property
    @pulumi.getter(name="attemptInterval")
    def attempt_interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Error retry interval, unit s, default value 30.
        """
        return pulumi.get(self, "attempt_interval")

    @attempt_interval.setter
    def attempt_interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "attempt_interval", value)

    @property
    @pulumi.getter(name="className")
    def class_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Full path of the task interface class.

        This field is available only when your task is of the Java task type.
        """
        return pulumi.get(self, "class_name")

    @class_name.setter
    def class_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "class_name", value)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The script code of the python, shell, and go task types.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="failTimes")
    def fail_times(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of consecutive failed alarms
        """
        return pulumi.get(self, "fail_times")

    @fail_times.setter
    def fail_times(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "fail_times", value)

    @property
    @pulumi.getter(name="jobMonitorInfo")
    def job_monitor_info(self) -> Optional[pulumi.Input['JobJobMonitorInfoArgs']]:
        """
        Task monitoring information See `job_monitor_info` below.
        """
        return pulumi.get(self, "job_monitor_info")

    @job_monitor_info.setter
    def job_monitor_info(self, value: Optional[pulumi.Input['JobJobMonitorInfoArgs']]):
        pulumi.set(self, "job_monitor_info", value)

    @property
    @pulumi.getter(name="mapTaskXattrs")
    def map_task_xattrs(self) -> Optional[pulumi.Input['JobMapTaskXattrsArgs']]:
        """
        Advanced configuration, limited to parallel computing, memory grid, and grid computing. See `map_task_xattrs` below.
        """
        return pulumi.get(self, "map_task_xattrs")

    @map_task_xattrs.setter
    def map_task_xattrs(self, value: Optional[pulumi.Input['JobMapTaskXattrsArgs']]):
        pulumi.set(self, "map_task_xattrs", value)

    @property
    @pulumi.getter(name="maxAttempt")
    def max_attempt(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of error retries, which is set based on business requirements. The default value is 0.
        """
        return pulumi.get(self, "max_attempt")

    @max_attempt.setter
    def max_attempt(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_attempt", value)

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "max_concurrency", value)

    @property
    @pulumi.getter(name="namespaceSource")
    def namespace_source(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Special third parties are required.
        """
        return pulumi.get(self, "namespace_source")

    @namespace_source.setter
    def namespace_source(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace_source", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User-defined parameters, which can be obtained at runtime.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task status. The values are as follows:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="successNoticeEnable")
    def success_notice_enable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Success Notification Switch
        """
        return pulumi.get(self, "success_notice_enable")

    @success_notice_enable.setter
    def success_notice_enable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "success_notice_enable", value)

    @property
    @pulumi.getter(name="taskDispatchMode")
    def task_dispatch_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Advanced configuration of parallel grid tasks, push model or pull model
        """
        return pulumi.get(self, "task_dispatch_mode")

    @task_dispatch_mode.setter
    def task_dispatch_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "task_dispatch_mode", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        K8s task type custom task template
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter
    def timezone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time Zone
        """
        return pulumi.get(self, "timezone")

    @timezone.setter
    def timezone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "timezone", value)

    @property
    @pulumi.getter(name="xAttrs")
    def x_attrs(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task Extension Field
        """
        return pulumi.get(self, "x_attrs")

    @x_attrs.setter
    def x_attrs(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "x_attrs", value)


@pulumi.input_type
class _JobState:
    def __init__(__self__, *,
                 attempt_interval: Optional[pulumi.Input[builtins.int]] = None,
                 class_name: Optional[pulumi.Input[builtins.str]] = None,
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 execute_mode: Optional[pulumi.Input[builtins.str]] = None,
                 fail_times: Optional[pulumi.Input[builtins.int]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 job_id: Optional[pulumi.Input[builtins.int]] = None,
                 job_monitor_info: Optional[pulumi.Input['JobJobMonitorInfoArgs']] = None,
                 job_name: Optional[pulumi.Input[builtins.str]] = None,
                 job_type: Optional[pulumi.Input[builtins.str]] = None,
                 map_task_xattrs: Optional[pulumi.Input['JobMapTaskXattrsArgs']] = None,
                 max_attempt: Optional[pulumi.Input[builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.str]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 namespace_source: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 success_notice_enable: Optional[pulumi.Input[builtins.bool]] = None,
                 task_dispatch_mode: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input[builtins.str]] = None,
                 time_config: Optional[pulumi.Input['JobTimeConfigArgs']] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None,
                 x_attrs: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Job resources.
        :param pulumi.Input[builtins.int] attempt_interval: Error retry interval, unit s, default value 30.
        :param pulumi.Input[builtins.str] class_name: Full path of the task interface class.
               
               This field is available only when your task is of the Java task type.
        :param pulumi.Input[builtins.str] content: The script code of the python, shell, and go task types.
        :param pulumi.Input[builtins.str] description: Task description.
        :param pulumi.Input[builtins.str] execute_mode: Task execution mode, the possible results are as follows:
        :param pulumi.Input[builtins.int] fail_times: Number of consecutive failed alarms
        :param pulumi.Input[builtins.str] group_id: The application ID, which is obtained from the **application management** page of the console.
        :param pulumi.Input[builtins.int] job_id: JobId
        :param pulumi.Input['JobJobMonitorInfoArgs'] job_monitor_info: Task monitoring information See `job_monitor_info` below.
        :param pulumi.Input[builtins.str] job_name: JobName
        :param pulumi.Input[builtins.str] job_type: Job Type
        :param pulumi.Input['JobMapTaskXattrsArgs'] map_task_xattrs: Advanced configuration, limited to parallel computing, memory grid, and grid computing. See `map_task_xattrs` below.
        :param pulumi.Input[builtins.int] max_attempt: The maximum number of error retries, which is set based on business requirements. The default value is 0.
        :param pulumi.Input[builtins.str] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[builtins.str] namespace: Namespace, which is obtained on the `Namespace` page of the console.
        :param pulumi.Input[builtins.str] namespace_source: Special third parties are required.
        :param pulumi.Input[builtins.str] parameters: User-defined parameters, which can be obtained at runtime.
        :param pulumi.Input[builtins.str] status: Task status. The values are as follows:
        :param pulumi.Input[builtins.bool] success_notice_enable: Success Notification Switch
        :param pulumi.Input[builtins.str] task_dispatch_mode: Advanced configuration of parallel grid tasks, push model or pull model
        :param pulumi.Input[builtins.str] template: K8s task type custom task template
        :param pulumi.Input['JobTimeConfigArgs'] time_config: Time configuration information See `time_config` below.
        :param pulumi.Input[builtins.str] timezone: Time Zone
        :param pulumi.Input[builtins.str] x_attrs: Task Extension Field
        """
        if attempt_interval is not None:
            pulumi.set(__self__, "attempt_interval", attempt_interval)
        if class_name is not None:
            pulumi.set(__self__, "class_name", class_name)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if execute_mode is not None:
            pulumi.set(__self__, "execute_mode", execute_mode)
        if fail_times is not None:
            pulumi.set(__self__, "fail_times", fail_times)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if job_id is not None:
            pulumi.set(__self__, "job_id", job_id)
        if job_monitor_info is not None:
            pulumi.set(__self__, "job_monitor_info", job_monitor_info)
        if job_name is not None:
            pulumi.set(__self__, "job_name", job_name)
        if job_type is not None:
            pulumi.set(__self__, "job_type", job_type)
        if map_task_xattrs is not None:
            pulumi.set(__self__, "map_task_xattrs", map_task_xattrs)
        if max_attempt is not None:
            pulumi.set(__self__, "max_attempt", max_attempt)
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if namespace_source is not None:
            pulumi.set(__self__, "namespace_source", namespace_source)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if success_notice_enable is not None:
            pulumi.set(__self__, "success_notice_enable", success_notice_enable)
        if task_dispatch_mode is not None:
            pulumi.set(__self__, "task_dispatch_mode", task_dispatch_mode)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if time_config is not None:
            pulumi.set(__self__, "time_config", time_config)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)
        if x_attrs is not None:
            pulumi.set(__self__, "x_attrs", x_attrs)

    @property
    @pulumi.getter(name="attemptInterval")
    def attempt_interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Error retry interval, unit s, default value 30.
        """
        return pulumi.get(self, "attempt_interval")

    @attempt_interval.setter
    def attempt_interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "attempt_interval", value)

    @property
    @pulumi.getter(name="className")
    def class_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Full path of the task interface class.

        This field is available only when your task is of the Java task type.
        """
        return pulumi.get(self, "class_name")

    @class_name.setter
    def class_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "class_name", value)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The script code of the python, shell, and go task types.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="executeMode")
    def execute_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task execution mode, the possible results are as follows:
        """
        return pulumi.get(self, "execute_mode")

    @execute_mode.setter
    def execute_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "execute_mode", value)

    @property
    @pulumi.getter(name="failTimes")
    def fail_times(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of consecutive failed alarms
        """
        return pulumi.get(self, "fail_times")

    @fail_times.setter
    def fail_times(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "fail_times", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The application ID, which is obtained from the **application management** page of the console.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="jobId")
    def job_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        JobId
        """
        return pulumi.get(self, "job_id")

    @job_id.setter
    def job_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "job_id", value)

    @property
    @pulumi.getter(name="jobMonitorInfo")
    def job_monitor_info(self) -> Optional[pulumi.Input['JobJobMonitorInfoArgs']]:
        """
        Task monitoring information See `job_monitor_info` below.
        """
        return pulumi.get(self, "job_monitor_info")

    @job_monitor_info.setter
    def job_monitor_info(self, value: Optional[pulumi.Input['JobJobMonitorInfoArgs']]):
        pulumi.set(self, "job_monitor_info", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        JobName
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter(name="jobType")
    def job_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Job Type
        """
        return pulumi.get(self, "job_type")

    @job_type.setter
    def job_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "job_type", value)

    @property
    @pulumi.getter(name="mapTaskXattrs")
    def map_task_xattrs(self) -> Optional[pulumi.Input['JobMapTaskXattrsArgs']]:
        """
        Advanced configuration, limited to parallel computing, memory grid, and grid computing. See `map_task_xattrs` below.
        """
        return pulumi.get(self, "map_task_xattrs")

    @map_task_xattrs.setter
    def map_task_xattrs(self, value: Optional[pulumi.Input['JobMapTaskXattrsArgs']]):
        pulumi.set(self, "map_task_xattrs", value)

    @property
    @pulumi.getter(name="maxAttempt")
    def max_attempt(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of error retries, which is set based on business requirements. The default value is 0.
        """
        return pulumi.get(self, "max_attempt")

    @max_attempt.setter
    def max_attempt(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_attempt", value)

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "max_concurrency", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Namespace, which is obtained on the `Namespace` page of the console.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="namespaceSource")
    def namespace_source(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Special third parties are required.
        """
        return pulumi.get(self, "namespace_source")

    @namespace_source.setter
    def namespace_source(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace_source", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User-defined parameters, which can be obtained at runtime.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task status. The values are as follows:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="successNoticeEnable")
    def success_notice_enable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Success Notification Switch
        """
        return pulumi.get(self, "success_notice_enable")

    @success_notice_enable.setter
    def success_notice_enable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "success_notice_enable", value)

    @property
    @pulumi.getter(name="taskDispatchMode")
    def task_dispatch_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Advanced configuration of parallel grid tasks, push model or pull model
        """
        return pulumi.get(self, "task_dispatch_mode")

    @task_dispatch_mode.setter
    def task_dispatch_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "task_dispatch_mode", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        K8s task type custom task template
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter(name="timeConfig")
    def time_config(self) -> Optional[pulumi.Input['JobTimeConfigArgs']]:
        """
        Time configuration information See `time_config` below.
        """
        return pulumi.get(self, "time_config")

    @time_config.setter
    def time_config(self, value: Optional[pulumi.Input['JobTimeConfigArgs']]):
        pulumi.set(self, "time_config", value)

    @property
    @pulumi.getter
    def timezone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time Zone
        """
        return pulumi.get(self, "timezone")

    @timezone.setter
    def timezone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "timezone", value)

    @property
    @pulumi.getter(name="xAttrs")
    def x_attrs(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task Extension Field
        """
        return pulumi.get(self, "x_attrs")

    @x_attrs.setter
    def x_attrs(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "x_attrs", value)


@pulumi.type_token("alicloud:schedulerx/job:Job")
class Job(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attempt_interval: Optional[pulumi.Input[builtins.int]] = None,
                 class_name: Optional[pulumi.Input[builtins.str]] = None,
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 execute_mode: Optional[pulumi.Input[builtins.str]] = None,
                 fail_times: Optional[pulumi.Input[builtins.int]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 job_monitor_info: Optional[pulumi.Input[Union['JobJobMonitorInfoArgs', 'JobJobMonitorInfoArgsDict']]] = None,
                 job_name: Optional[pulumi.Input[builtins.str]] = None,
                 job_type: Optional[pulumi.Input[builtins.str]] = None,
                 map_task_xattrs: Optional[pulumi.Input[Union['JobMapTaskXattrsArgs', 'JobMapTaskXattrsArgsDict']]] = None,
                 max_attempt: Optional[pulumi.Input[builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.str]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 namespace_source: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 success_notice_enable: Optional[pulumi.Input[builtins.bool]] = None,
                 task_dispatch_mode: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input[builtins.str]] = None,
                 time_config: Optional[pulumi.Input[Union['JobTimeConfigArgs', 'JobTimeConfigArgsDict']]] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None,
                 x_attrs: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Schedulerx Job resource.

        For information about Schedulerx Job and how to use it, see [What is Job](https://www.alibabacloud.com/help/en/schedulerx/schedulerx-serverless/developer-reference/api-schedulerx2-2019-04-30-createjob).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        create_name_space = alicloud.schedulerx.Namespace("CreateNameSpace",
            namespace_name=name,
            description=name)
        default = alicloud.schedulerx.AppGroup("default",
            max_jobs=100,
            monitor_contacts_json=json.dumps([
                {
                    "userName": "name1",
                    "userPhone": "89756******",
                },
                {
                    "userName": "name2",
                    "ding": "http://www.example.com",
                },
            ]),
            delete_jobs=False,
            app_type=1,
            namespace_source="schedulerx",
            group_id="example-appgroup-pop-autoexample",
            namespace_name="default",
            description=name,
            monitor_config_json=json.dumps({
                "sendChannel": "sms,ding",
            }),
            app_version="1",
            app_name="example-appgroup-pop-autoexample",
            namespace=create_name_space.namespace_uid,
            enable_log=False,
            schedule_busy_workers=False)
        default_job = alicloud.schedulerx.Job("default",
            timezone="GTM+7",
            status="Enable",
            max_attempt=0,
            description=name,
            parameters="hello word",
            job_name=name,
            max_concurrency="1",
            time_config={
                "data_offset": 1,
                "time_expression": "100000",
                "time_type": 3,
                "calendar": "workday",
            },
            map_task_xattrs={
                "task_max_attempt": 1,
                "task_attempt_interval": 1,
                "consumer_size": 5,
                "queue_size": 10000,
                "dispatcher_size": 5,
                "page_size": 100,
            },
            namespace=create_name_space.namespace_uid,
            group_id=default.group_id,
            job_type="java",
            job_monitor_info={
                "contact_infos": [
                    {
                        "user_phone": "12345678910",
                        "user_name": "tangtao-1",
                        "ding": "https://alidocs.dingtalk.com",
                        "user_mail": "12345678@xx.com",
                    },
                    {
                        "user_phone": "12345678910",
                        "user_name": "tangtao-2",
                        "ding": "https://alidocs.dingtalk.com1",
                        "user_mail": "123456789@xx.com",
                    },
                ],
                "monitor_config": {
                    "timeout": 7200,
                    "send_channel": "sms",
                    "timeout_kill_enable": True,
                    "timeout_enable": True,
                    "fail_enable": True,
                    "miss_worker_enable": True,
                },
            },
            class_name="com.aliyun.schedulerx.example.processor.SimpleJob",
            namespace_source="schedulerx",
            attempt_interval=30,
            fail_times=1,
            execute_mode="batch")
        ```

        ## Import

        Schedulerx Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:schedulerx/job:Job example <namespace>:<group_id>:<job_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] attempt_interval: Error retry interval, unit s, default value 30.
        :param pulumi.Input[builtins.str] class_name: Full path of the task interface class.
               
               This field is available only when your task is of the Java task type.
        :param pulumi.Input[builtins.str] content: The script code of the python, shell, and go task types.
        :param pulumi.Input[builtins.str] description: Task description.
        :param pulumi.Input[builtins.str] execute_mode: Task execution mode, the possible results are as follows:
        :param pulumi.Input[builtins.int] fail_times: Number of consecutive failed alarms
        :param pulumi.Input[builtins.str] group_id: The application ID, which is obtained from the **application management** page of the console.
        :param pulumi.Input[Union['JobJobMonitorInfoArgs', 'JobJobMonitorInfoArgsDict']] job_monitor_info: Task monitoring information See `job_monitor_info` below.
        :param pulumi.Input[builtins.str] job_name: JobName
        :param pulumi.Input[builtins.str] job_type: Job Type
        :param pulumi.Input[Union['JobMapTaskXattrsArgs', 'JobMapTaskXattrsArgsDict']] map_task_xattrs: Advanced configuration, limited to parallel computing, memory grid, and grid computing. See `map_task_xattrs` below.
        :param pulumi.Input[builtins.int] max_attempt: The maximum number of error retries, which is set based on business requirements. The default value is 0.
        :param pulumi.Input[builtins.str] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[builtins.str] namespace: Namespace, which is obtained on the `Namespace` page of the console.
        :param pulumi.Input[builtins.str] namespace_source: Special third parties are required.
        :param pulumi.Input[builtins.str] parameters: User-defined parameters, which can be obtained at runtime.
        :param pulumi.Input[builtins.str] status: Task status. The values are as follows:
        :param pulumi.Input[builtins.bool] success_notice_enable: Success Notification Switch
        :param pulumi.Input[builtins.str] task_dispatch_mode: Advanced configuration of parallel grid tasks, push model or pull model
        :param pulumi.Input[builtins.str] template: K8s task type custom task template
        :param pulumi.Input[Union['JobTimeConfigArgs', 'JobTimeConfigArgsDict']] time_config: Time configuration information See `time_config` below.
        :param pulumi.Input[builtins.str] timezone: Time Zone
        :param pulumi.Input[builtins.str] x_attrs: Task Extension Field
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: JobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Schedulerx Job resource.

        For information about Schedulerx Job and how to use it, see [What is Job](https://www.alibabacloud.com/help/en/schedulerx/schedulerx-serverless/developer-reference/api-schedulerx2-2019-04-30-createjob).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        create_name_space = alicloud.schedulerx.Namespace("CreateNameSpace",
            namespace_name=name,
            description=name)
        default = alicloud.schedulerx.AppGroup("default",
            max_jobs=100,
            monitor_contacts_json=json.dumps([
                {
                    "userName": "name1",
                    "userPhone": "89756******",
                },
                {
                    "userName": "name2",
                    "ding": "http://www.example.com",
                },
            ]),
            delete_jobs=False,
            app_type=1,
            namespace_source="schedulerx",
            group_id="example-appgroup-pop-autoexample",
            namespace_name="default",
            description=name,
            monitor_config_json=json.dumps({
                "sendChannel": "sms,ding",
            }),
            app_version="1",
            app_name="example-appgroup-pop-autoexample",
            namespace=create_name_space.namespace_uid,
            enable_log=False,
            schedule_busy_workers=False)
        default_job = alicloud.schedulerx.Job("default",
            timezone="GTM+7",
            status="Enable",
            max_attempt=0,
            description=name,
            parameters="hello word",
            job_name=name,
            max_concurrency="1",
            time_config={
                "data_offset": 1,
                "time_expression": "100000",
                "time_type": 3,
                "calendar": "workday",
            },
            map_task_xattrs={
                "task_max_attempt": 1,
                "task_attempt_interval": 1,
                "consumer_size": 5,
                "queue_size": 10000,
                "dispatcher_size": 5,
                "page_size": 100,
            },
            namespace=create_name_space.namespace_uid,
            group_id=default.group_id,
            job_type="java",
            job_monitor_info={
                "contact_infos": [
                    {
                        "user_phone": "12345678910",
                        "user_name": "tangtao-1",
                        "ding": "https://alidocs.dingtalk.com",
                        "user_mail": "12345678@xx.com",
                    },
                    {
                        "user_phone": "12345678910",
                        "user_name": "tangtao-2",
                        "ding": "https://alidocs.dingtalk.com1",
                        "user_mail": "123456789@xx.com",
                    },
                ],
                "monitor_config": {
                    "timeout": 7200,
                    "send_channel": "sms",
                    "timeout_kill_enable": True,
                    "timeout_enable": True,
                    "fail_enable": True,
                    "miss_worker_enable": True,
                },
            },
            class_name="com.aliyun.schedulerx.example.processor.SimpleJob",
            namespace_source="schedulerx",
            attempt_interval=30,
            fail_times=1,
            execute_mode="batch")
        ```

        ## Import

        Schedulerx Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:schedulerx/job:Job example <namespace>:<group_id>:<job_id>
        ```

        :param str resource_name: The name of the resource.
        :param JobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(JobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attempt_interval: Optional[pulumi.Input[builtins.int]] = None,
                 class_name: Optional[pulumi.Input[builtins.str]] = None,
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 execute_mode: Optional[pulumi.Input[builtins.str]] = None,
                 fail_times: Optional[pulumi.Input[builtins.int]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 job_monitor_info: Optional[pulumi.Input[Union['JobJobMonitorInfoArgs', 'JobJobMonitorInfoArgsDict']]] = None,
                 job_name: Optional[pulumi.Input[builtins.str]] = None,
                 job_type: Optional[pulumi.Input[builtins.str]] = None,
                 map_task_xattrs: Optional[pulumi.Input[Union['JobMapTaskXattrsArgs', 'JobMapTaskXattrsArgsDict']]] = None,
                 max_attempt: Optional[pulumi.Input[builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[builtins.str]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 namespace_source: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 success_notice_enable: Optional[pulumi.Input[builtins.bool]] = None,
                 task_dispatch_mode: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input[builtins.str]] = None,
                 time_config: Optional[pulumi.Input[Union['JobTimeConfigArgs', 'JobTimeConfigArgsDict']]] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None,
                 x_attrs: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = JobArgs.__new__(JobArgs)

            __props__.__dict__["attempt_interval"] = attempt_interval
            __props__.__dict__["class_name"] = class_name
            __props__.__dict__["content"] = content
            __props__.__dict__["description"] = description
            if execute_mode is None and not opts.urn:
                raise TypeError("Missing required property 'execute_mode'")
            __props__.__dict__["execute_mode"] = execute_mode
            __props__.__dict__["fail_times"] = fail_times
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["job_monitor_info"] = job_monitor_info
            if job_name is None and not opts.urn:
                raise TypeError("Missing required property 'job_name'")
            __props__.__dict__["job_name"] = job_name
            if job_type is None and not opts.urn:
                raise TypeError("Missing required property 'job_type'")
            __props__.__dict__["job_type"] = job_type
            __props__.__dict__["map_task_xattrs"] = map_task_xattrs
            __props__.__dict__["max_attempt"] = max_attempt
            __props__.__dict__["max_concurrency"] = max_concurrency
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["namespace_source"] = namespace_source
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["status"] = status
            __props__.__dict__["success_notice_enable"] = success_notice_enable
            __props__.__dict__["task_dispatch_mode"] = task_dispatch_mode
            __props__.__dict__["template"] = template
            if time_config is None and not opts.urn:
                raise TypeError("Missing required property 'time_config'")
            __props__.__dict__["time_config"] = time_config
            __props__.__dict__["timezone"] = timezone
            __props__.__dict__["x_attrs"] = x_attrs
            __props__.__dict__["job_id"] = None
        super(Job, __self__).__init__(
            'alicloud:schedulerx/job:Job',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attempt_interval: Optional[pulumi.Input[builtins.int]] = None,
            class_name: Optional[pulumi.Input[builtins.str]] = None,
            content: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            execute_mode: Optional[pulumi.Input[builtins.str]] = None,
            fail_times: Optional[pulumi.Input[builtins.int]] = None,
            group_id: Optional[pulumi.Input[builtins.str]] = None,
            job_id: Optional[pulumi.Input[builtins.int]] = None,
            job_monitor_info: Optional[pulumi.Input[Union['JobJobMonitorInfoArgs', 'JobJobMonitorInfoArgsDict']]] = None,
            job_name: Optional[pulumi.Input[builtins.str]] = None,
            job_type: Optional[pulumi.Input[builtins.str]] = None,
            map_task_xattrs: Optional[pulumi.Input[Union['JobMapTaskXattrsArgs', 'JobMapTaskXattrsArgsDict']]] = None,
            max_attempt: Optional[pulumi.Input[builtins.int]] = None,
            max_concurrency: Optional[pulumi.Input[builtins.str]] = None,
            namespace: Optional[pulumi.Input[builtins.str]] = None,
            namespace_source: Optional[pulumi.Input[builtins.str]] = None,
            parameters: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            success_notice_enable: Optional[pulumi.Input[builtins.bool]] = None,
            task_dispatch_mode: Optional[pulumi.Input[builtins.str]] = None,
            template: Optional[pulumi.Input[builtins.str]] = None,
            time_config: Optional[pulumi.Input[Union['JobTimeConfigArgs', 'JobTimeConfigArgsDict']]] = None,
            timezone: Optional[pulumi.Input[builtins.str]] = None,
            x_attrs: Optional[pulumi.Input[builtins.str]] = None) -> 'Job':
        """
        Get an existing Job resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] attempt_interval: Error retry interval, unit s, default value 30.
        :param pulumi.Input[builtins.str] class_name: Full path of the task interface class.
               
               This field is available only when your task is of the Java task type.
        :param pulumi.Input[builtins.str] content: The script code of the python, shell, and go task types.
        :param pulumi.Input[builtins.str] description: Task description.
        :param pulumi.Input[builtins.str] execute_mode: Task execution mode, the possible results are as follows:
        :param pulumi.Input[builtins.int] fail_times: Number of consecutive failed alarms
        :param pulumi.Input[builtins.str] group_id: The application ID, which is obtained from the **application management** page of the console.
        :param pulumi.Input[builtins.int] job_id: JobId
        :param pulumi.Input[Union['JobJobMonitorInfoArgs', 'JobJobMonitorInfoArgsDict']] job_monitor_info: Task monitoring information See `job_monitor_info` below.
        :param pulumi.Input[builtins.str] job_name: JobName
        :param pulumi.Input[builtins.str] job_type: Job Type
        :param pulumi.Input[Union['JobMapTaskXattrsArgs', 'JobMapTaskXattrsArgsDict']] map_task_xattrs: Advanced configuration, limited to parallel computing, memory grid, and grid computing. See `map_task_xattrs` below.
        :param pulumi.Input[builtins.int] max_attempt: The maximum number of error retries, which is set based on business requirements. The default value is 0.
        :param pulumi.Input[builtins.str] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[builtins.str] namespace: Namespace, which is obtained on the `Namespace` page of the console.
        :param pulumi.Input[builtins.str] namespace_source: Special third parties are required.
        :param pulumi.Input[builtins.str] parameters: User-defined parameters, which can be obtained at runtime.
        :param pulumi.Input[builtins.str] status: Task status. The values are as follows:
        :param pulumi.Input[builtins.bool] success_notice_enable: Success Notification Switch
        :param pulumi.Input[builtins.str] task_dispatch_mode: Advanced configuration of parallel grid tasks, push model or pull model
        :param pulumi.Input[builtins.str] template: K8s task type custom task template
        :param pulumi.Input[Union['JobTimeConfigArgs', 'JobTimeConfigArgsDict']] time_config: Time configuration information See `time_config` below.
        :param pulumi.Input[builtins.str] timezone: Time Zone
        :param pulumi.Input[builtins.str] x_attrs: Task Extension Field
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _JobState.__new__(_JobState)

        __props__.__dict__["attempt_interval"] = attempt_interval
        __props__.__dict__["class_name"] = class_name
        __props__.__dict__["content"] = content
        __props__.__dict__["description"] = description
        __props__.__dict__["execute_mode"] = execute_mode
        __props__.__dict__["fail_times"] = fail_times
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["job_id"] = job_id
        __props__.__dict__["job_monitor_info"] = job_monitor_info
        __props__.__dict__["job_name"] = job_name
        __props__.__dict__["job_type"] = job_type
        __props__.__dict__["map_task_xattrs"] = map_task_xattrs
        __props__.__dict__["max_attempt"] = max_attempt
        __props__.__dict__["max_concurrency"] = max_concurrency
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["namespace_source"] = namespace_source
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["status"] = status
        __props__.__dict__["success_notice_enable"] = success_notice_enable
        __props__.__dict__["task_dispatch_mode"] = task_dispatch_mode
        __props__.__dict__["template"] = template
        __props__.__dict__["time_config"] = time_config
        __props__.__dict__["timezone"] = timezone
        __props__.__dict__["x_attrs"] = x_attrs
        return Job(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="attemptInterval")
    def attempt_interval(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Error retry interval, unit s, default value 30.
        """
        return pulumi.get(self, "attempt_interval")

    @property
    @pulumi.getter(name="className")
    def class_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Full path of the task interface class.

        This field is available only when your task is of the Java task type.
        """
        return pulumi.get(self, "class_name")

    @property
    @pulumi.getter
    def content(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The script code of the python, shell, and go task types.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Task description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="executeMode")
    def execute_mode(self) -> pulumi.Output[builtins.str]:
        """
        Task execution mode, the possible results are as follows:
        """
        return pulumi.get(self, "execute_mode")

    @property
    @pulumi.getter(name="failTimes")
    def fail_times(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Number of consecutive failed alarms
        """
        return pulumi.get(self, "fail_times")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[builtins.str]:
        """
        The application ID, which is obtained from the **application management** page of the console.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="jobId")
    def job_id(self) -> pulumi.Output[builtins.int]:
        """
        JobId
        """
        return pulumi.get(self, "job_id")

    @property
    @pulumi.getter(name="jobMonitorInfo")
    def job_monitor_info(self) -> pulumi.Output[Optional['outputs.JobJobMonitorInfo']]:
        """
        Task monitoring information See `job_monitor_info` below.
        """
        return pulumi.get(self, "job_monitor_info")

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Output[builtins.str]:
        """
        JobName
        """
        return pulumi.get(self, "job_name")

    @property
    @pulumi.getter(name="jobType")
    def job_type(self) -> pulumi.Output[builtins.str]:
        """
        Job Type
        """
        return pulumi.get(self, "job_type")

    @property
    @pulumi.getter(name="mapTaskXattrs")
    def map_task_xattrs(self) -> pulumi.Output[Optional['outputs.JobMapTaskXattrs']]:
        """
        Advanced configuration, limited to parallel computing, memory grid, and grid computing. See `map_task_xattrs` below.
        """
        return pulumi.get(self, "map_task_xattrs")

    @property
    @pulumi.getter(name="maxAttempt")
    def max_attempt(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The maximum number of error retries, which is set based on business requirements. The default value is 0.
        """
        return pulumi.get(self, "max_attempt")

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        """
        return pulumi.get(self, "max_concurrency")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[builtins.str]:
        """
        Namespace, which is obtained on the `Namespace` page of the console.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="namespaceSource")
    def namespace_source(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Special third parties are required.
        """
        return pulumi.get(self, "namespace_source")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        User-defined parameters, which can be obtained at runtime.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Task status. The values are as follows:
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="successNoticeEnable")
    def success_notice_enable(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Success Notification Switch
        """
        return pulumi.get(self, "success_notice_enable")

    @property
    @pulumi.getter(name="taskDispatchMode")
    def task_dispatch_mode(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Advanced configuration of parallel grid tasks, push model or pull model
        """
        return pulumi.get(self, "task_dispatch_mode")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        K8s task type custom task template
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter(name="timeConfig")
    def time_config(self) -> pulumi.Output['outputs.JobTimeConfig']:
        """
        Time configuration information See `time_config` below.
        """
        return pulumi.get(self, "time_config")

    @property
    @pulumi.getter
    def timezone(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Time Zone
        """
        return pulumi.get(self, "timezone")

    @property
    @pulumi.getter(name="xAttrs")
    def x_attrs(self) -> pulumi.Output[builtins.str]:
        """
        Task Extension Field
        """
        return pulumi.get(self, "x_attrs")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RouterGrantAssociationArgs', 'RouterGrantAssociation']

@pulumi.input_type
class RouterGrantAssociationArgs:
    def __init__(__self__, *,
                 ecr_id: pulumi.Input[builtins.str],
                 ecr_owner_ali_uid: pulumi.Input[builtins.int],
                 instance_id: pulumi.Input[builtins.str],
                 instance_region_id: pulumi.Input[builtins.str],
                 instance_type: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a RouterGrantAssociation resource.
        :param pulumi.Input[builtins.str] ecr_id: The ID of the associated Leased Line Gateway instance.
        :param pulumi.Input[builtins.int] ecr_owner_ali_uid: The ID of the Alibaba Cloud account (primary account) to which the leased line gateway instance is authorized.
        :param pulumi.Input[builtins.str] instance_id: The ID of the network instance.
        :param pulumi.Input[builtins.str] instance_region_id: The ID of the region where the authorized network instance is located.
        :param pulumi.Input[builtins.str] instance_type: The type of the network instance. Value:
               - `VBR`: the VBR instance.
               - `VPC`: VPC instance.
        """
        pulumi.set(__self__, "ecr_id", ecr_id)
        pulumi.set(__self__, "ecr_owner_ali_uid", ecr_owner_ali_uid)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_region_id", instance_region_id)
        pulumi.set(__self__, "instance_type", instance_type)

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the associated Leased Line Gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @ecr_id.setter
    def ecr_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ecr_id", value)

    @property
    @pulumi.getter(name="ecrOwnerAliUid")
    def ecr_owner_ali_uid(self) -> pulumi.Input[builtins.int]:
        """
        The ID of the Alibaba Cloud account (primary account) to which the leased line gateway instance is authorized.
        """
        return pulumi.get(self, "ecr_owner_ali_uid")

    @ecr_owner_ali_uid.setter
    def ecr_owner_ali_uid(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "ecr_owner_ali_uid", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the network instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceRegionId")
    def instance_region_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the region where the authorized network instance is located.
        """
        return pulumi.get(self, "instance_region_id")

    @instance_region_id.setter
    def instance_region_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_region_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[builtins.str]:
        """
        The type of the network instance. Value:
        - `VBR`: the VBR instance.
        - `VPC`: VPC instance.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_type", value)


@pulumi.input_type
class _RouterGrantAssociationState:
    def __init__(__self__, *,
                 ecr_id: Optional[pulumi.Input[builtins.str]] = None,
                 ecr_owner_ali_uid: Optional[pulumi.Input[builtins.int]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RouterGrantAssociation resources.
        :param pulumi.Input[builtins.str] ecr_id: The ID of the associated Leased Line Gateway instance.
        :param pulumi.Input[builtins.int] ecr_owner_ali_uid: The ID of the Alibaba Cloud account (primary account) to which the leased line gateway instance is authorized.
        :param pulumi.Input[builtins.str] instance_id: The ID of the network instance.
        :param pulumi.Input[builtins.str] instance_region_id: The ID of the region where the authorized network instance is located.
        :param pulumi.Input[builtins.str] instance_type: The type of the network instance. Value:
               - `VBR`: the VBR instance.
               - `VPC`: VPC instance.
        :param pulumi.Input[builtins.str] status: The status of the resource
        """
        if ecr_id is not None:
            pulumi.set(__self__, "ecr_id", ecr_id)
        if ecr_owner_ali_uid is not None:
            pulumi.set(__self__, "ecr_owner_ali_uid", ecr_owner_ali_uid)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_region_id is not None:
            pulumi.set(__self__, "instance_region_id", instance_region_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the associated Leased Line Gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @ecr_id.setter
    def ecr_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ecr_id", value)

    @property
    @pulumi.getter(name="ecrOwnerAliUid")
    def ecr_owner_ali_uid(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the Alibaba Cloud account (primary account) to which the leased line gateway instance is authorized.
        """
        return pulumi.get(self, "ecr_owner_ali_uid")

    @ecr_owner_ali_uid.setter
    def ecr_owner_ali_uid(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ecr_owner_ali_uid", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the network instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceRegionId")
    def instance_region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the region where the authorized network instance is located.
        """
        return pulumi.get(self, "instance_region_id")

    @instance_region_id.setter
    def instance_region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_region_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the network instance. Value:
        - `VBR`: the VBR instance.
        - `VPC`: VPC instance.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:expressconnect/routerGrantAssociation:RouterGrantAssociation")
class RouterGrantAssociation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ecr_id: Optional[pulumi.Input[builtins.str]] = None,
                 ecr_owner_ali_uid: Optional[pulumi.Input[builtins.int]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Router Grant Association resource.

        Network instances authorized to the leased line Gateway.

        For information about Express Connect Router Grant Association and how to use it, see [What is Grant Association](https://www.alibabacloud.com/help/en/express-connect/developer-reference/api-expressconnectrouter-2023-09-01-grantinstancetoexpressconnectrouter).

        > **NOTE:** Available since v1.239.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vpc_id = config.get("vpcId")
        if vpc_id is None:
            vpc_id = "vpc-xxx"
        ecr_owner_uid = config.get("ecrOwnerUid")
        if ecr_owner_uid is None:
            ecr_owner_uid = "18xxx"
        ecr_id = config.get("ecrId")
        if ecr_id is None:
            ecr_id = "ecr-xxx"
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        default = alicloud.expressconnect.RouterGrantAssociation("default",
            ecr_id=ecr_id,
            instance_region_id=region,
            instance_id=vpc_id,
            ecr_owner_ali_uid=ecr_owner_uid,
            instance_type="VPC")
        ```

        ## Import

        Express Connect Router Grant Association can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/routerGrantAssociation:RouterGrantAssociation example <ecr_id>:<instance_id>:<instance_region_id>:<ecr_owner_ali_uid>:<instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ecr_id: The ID of the associated Leased Line Gateway instance.
        :param pulumi.Input[builtins.int] ecr_owner_ali_uid: The ID of the Alibaba Cloud account (primary account) to which the leased line gateway instance is authorized.
        :param pulumi.Input[builtins.str] instance_id: The ID of the network instance.
        :param pulumi.Input[builtins.str] instance_region_id: The ID of the region where the authorized network instance is located.
        :param pulumi.Input[builtins.str] instance_type: The type of the network instance. Value:
               - `VBR`: the VBR instance.
               - `VPC`: VPC instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouterGrantAssociationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Router Grant Association resource.

        Network instances authorized to the leased line Gateway.

        For information about Express Connect Router Grant Association and how to use it, see [What is Grant Association](https://www.alibabacloud.com/help/en/express-connect/developer-reference/api-expressconnectrouter-2023-09-01-grantinstancetoexpressconnectrouter).

        > **NOTE:** Available since v1.239.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vpc_id = config.get("vpcId")
        if vpc_id is None:
            vpc_id = "vpc-xxx"
        ecr_owner_uid = config.get("ecrOwnerUid")
        if ecr_owner_uid is None:
            ecr_owner_uid = "18xxx"
        ecr_id = config.get("ecrId")
        if ecr_id is None:
            ecr_id = "ecr-xxx"
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        default = alicloud.expressconnect.RouterGrantAssociation("default",
            ecr_id=ecr_id,
            instance_region_id=region,
            instance_id=vpc_id,
            ecr_owner_ali_uid=ecr_owner_uid,
            instance_type="VPC")
        ```

        ## Import

        Express Connect Router Grant Association can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/routerGrantAssociation:RouterGrantAssociation example <ecr_id>:<instance_id>:<instance_region_id>:<ecr_owner_ali_uid>:<instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param RouterGrantAssociationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouterGrantAssociationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ecr_id: Optional[pulumi.Input[builtins.str]] = None,
                 ecr_owner_ali_uid: Optional[pulumi.Input[builtins.int]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouterGrantAssociationArgs.__new__(RouterGrantAssociationArgs)

            if ecr_id is None and not opts.urn:
                raise TypeError("Missing required property 'ecr_id'")
            __props__.__dict__["ecr_id"] = ecr_id
            if ecr_owner_ali_uid is None and not opts.urn:
                raise TypeError("Missing required property 'ecr_owner_ali_uid'")
            __props__.__dict__["ecr_owner_ali_uid"] = ecr_owner_ali_uid
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if instance_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_region_id'")
            __props__.__dict__["instance_region_id"] = instance_region_id
            if instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type'")
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["status"] = None
        super(RouterGrantAssociation, __self__).__init__(
            'alicloud:expressconnect/routerGrantAssociation:RouterGrantAssociation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ecr_id: Optional[pulumi.Input[builtins.str]] = None,
            ecr_owner_ali_uid: Optional[pulumi.Input[builtins.int]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_region_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'RouterGrantAssociation':
        """
        Get an existing RouterGrantAssociation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ecr_id: The ID of the associated Leased Line Gateway instance.
        :param pulumi.Input[builtins.int] ecr_owner_ali_uid: The ID of the Alibaba Cloud account (primary account) to which the leased line gateway instance is authorized.
        :param pulumi.Input[builtins.str] instance_id: The ID of the network instance.
        :param pulumi.Input[builtins.str] instance_region_id: The ID of the region where the authorized network instance is located.
        :param pulumi.Input[builtins.str] instance_type: The type of the network instance. Value:
               - `VBR`: the VBR instance.
               - `VPC`: VPC instance.
        :param pulumi.Input[builtins.str] status: The status of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouterGrantAssociationState.__new__(_RouterGrantAssociationState)

        __props__.__dict__["ecr_id"] = ecr_id
        __props__.__dict__["ecr_owner_ali_uid"] = ecr_owner_ali_uid
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_region_id"] = instance_region_id
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["status"] = status
        return RouterGrantAssociation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the associated Leased Line Gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @property
    @pulumi.getter(name="ecrOwnerAliUid")
    def ecr_owner_ali_uid(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the Alibaba Cloud account (primary account) to which the leased line gateway instance is authorized.
        """
        return pulumi.get(self, "ecr_owner_ali_uid")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the network instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceRegionId")
    def instance_region_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the region where the authorized network instance is located.
        """
        return pulumi.get(self, "instance_region_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the network instance. Value:
        - `VBR`: the VBR instance.
        - `VPC`: VPC instance.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .cache_reserve_instance import *
from .cache_rule import *
from .certificate import *
from .client_ca_certificate import *
from .client_certificate import *
from .compression_rule import *
from .edge_container_app import *
from .edge_container_app_record import *
from .get_sites import *
from .http_request_header_modification_rule import *
from .http_response_header_modification_rule import *
from .https_application_configuration import *
from .https_basic_configuration import *
from .image_transform import *
from .kv_namespace import *
from .list import *
from .network_optimization import *
from .origin_pool import *
from .origin_rule import *
from .page import *
from .rate_plan_instance import *
from .record import *
from .redirect_rule import *
from .rewrite_url_rule import *
from .scheduled_preload_execution import *
from .scheduled_preload_job import *
from .site import *
from .site_delivery_task import *
from .waiting_room import *
from .waiting_room_event import *
from .waiting_room_rule import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AntiBruteForceRuleArgs', 'AntiBruteForceRule']

@pulumi.input_type
class AntiBruteForceRuleArgs:
    def __init__(__self__, *,
                 anti_brute_force_rule_name: pulumi.Input[builtins.str],
                 fail_count: pulumi.Input[builtins.int],
                 forbidden_time: pulumi.Input[builtins.int],
                 span: pulumi.Input[builtins.int],
                 uuid_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 default_rule: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a AntiBruteForceRule resource.
        :param pulumi.Input[builtins.str] anti_brute_force_rule_name: The name of the defense rule.
        :param pulumi.Input[builtins.int] fail_count: FailCount
        :param pulumi.Input[builtins.int] forbidden_time: The period of time during which logons from an account are not allowed. Unit: minutes. Valid values:
        :param pulumi.Input[builtins.int] span: The maximum period of time during which failed logon attempts from an account can occur. Unit: minutes. Valid values:
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] uuid_lists: The UUIDs of the servers to which you want to apply the defense rule.
        :param pulumi.Input[builtins.bool] default_rule: Specifies whether to set the defense rule as the default rule. Valid values:
        """
        pulumi.set(__self__, "anti_brute_force_rule_name", anti_brute_force_rule_name)
        pulumi.set(__self__, "fail_count", fail_count)
        pulumi.set(__self__, "forbidden_time", forbidden_time)
        pulumi.set(__self__, "span", span)
        pulumi.set(__self__, "uuid_lists", uuid_lists)
        if default_rule is not None:
            pulumi.set(__self__, "default_rule", default_rule)

    @property
    @pulumi.getter(name="antiBruteForceRuleName")
    def anti_brute_force_rule_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the defense rule.
        """
        return pulumi.get(self, "anti_brute_force_rule_name")

    @anti_brute_force_rule_name.setter
    def anti_brute_force_rule_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "anti_brute_force_rule_name", value)

    @property
    @pulumi.getter(name="failCount")
    def fail_count(self) -> pulumi.Input[builtins.int]:
        """
        FailCount
        """
        return pulumi.get(self, "fail_count")

    @fail_count.setter
    def fail_count(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "fail_count", value)

    @property
    @pulumi.getter(name="forbiddenTime")
    def forbidden_time(self) -> pulumi.Input[builtins.int]:
        """
        The period of time during which logons from an account are not allowed. Unit: minutes. Valid values:
        """
        return pulumi.get(self, "forbidden_time")

    @forbidden_time.setter
    def forbidden_time(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "forbidden_time", value)

    @property
    @pulumi.getter
    def span(self) -> pulumi.Input[builtins.int]:
        """
        The maximum period of time during which failed logon attempts from an account can occur. Unit: minutes. Valid values:
        """
        return pulumi.get(self, "span")

    @span.setter
    def span(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "span", value)

    @property
    @pulumi.getter(name="uuidLists")
    def uuid_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        The UUIDs of the servers to which you want to apply the defense rule.
        """
        return pulumi.get(self, "uuid_lists")

    @uuid_lists.setter
    def uuid_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "uuid_lists", value)

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to set the defense rule as the default rule. Valid values:
        """
        return pulumi.get(self, "default_rule")

    @default_rule.setter
    def default_rule(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default_rule", value)


@pulumi.input_type
class _AntiBruteForceRuleState:
    def __init__(__self__, *,
                 anti_brute_force_rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 default_rule: Optional[pulumi.Input[builtins.bool]] = None,
                 fail_count: Optional[pulumi.Input[builtins.int]] = None,
                 forbidden_time: Optional[pulumi.Input[builtins.int]] = None,
                 span: Optional[pulumi.Input[builtins.int]] = None,
                 uuid_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AntiBruteForceRule resources.
        :param pulumi.Input[builtins.str] anti_brute_force_rule_name: The name of the defense rule.
        :param pulumi.Input[builtins.bool] default_rule: Specifies whether to set the defense rule as the default rule. Valid values:
        :param pulumi.Input[builtins.int] fail_count: FailCount
        :param pulumi.Input[builtins.int] forbidden_time: The period of time during which logons from an account are not allowed. Unit: minutes. Valid values:
        :param pulumi.Input[builtins.int] span: The maximum period of time during which failed logon attempts from an account can occur. Unit: minutes. Valid values:
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] uuid_lists: The UUIDs of the servers to which you want to apply the defense rule.
        """
        if anti_brute_force_rule_name is not None:
            pulumi.set(__self__, "anti_brute_force_rule_name", anti_brute_force_rule_name)
        if default_rule is not None:
            pulumi.set(__self__, "default_rule", default_rule)
        if fail_count is not None:
            pulumi.set(__self__, "fail_count", fail_count)
        if forbidden_time is not None:
            pulumi.set(__self__, "forbidden_time", forbidden_time)
        if span is not None:
            pulumi.set(__self__, "span", span)
        if uuid_lists is not None:
            pulumi.set(__self__, "uuid_lists", uuid_lists)

    @property
    @pulumi.getter(name="antiBruteForceRuleName")
    def anti_brute_force_rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the defense rule.
        """
        return pulumi.get(self, "anti_brute_force_rule_name")

    @anti_brute_force_rule_name.setter
    def anti_brute_force_rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "anti_brute_force_rule_name", value)

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to set the defense rule as the default rule. Valid values:
        """
        return pulumi.get(self, "default_rule")

    @default_rule.setter
    def default_rule(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default_rule", value)

    @property
    @pulumi.getter(name="failCount")
    def fail_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        FailCount
        """
        return pulumi.get(self, "fail_count")

    @fail_count.setter
    def fail_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "fail_count", value)

    @property
    @pulumi.getter(name="forbiddenTime")
    def forbidden_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The period of time during which logons from an account are not allowed. Unit: minutes. Valid values:
        """
        return pulumi.get(self, "forbidden_time")

    @forbidden_time.setter
    def forbidden_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "forbidden_time", value)

    @property
    @pulumi.getter
    def span(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum period of time during which failed logon attempts from an account can occur. Unit: minutes. Valid values:
        """
        return pulumi.get(self, "span")

    @span.setter
    def span(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "span", value)

    @property
    @pulumi.getter(name="uuidLists")
    def uuid_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The UUIDs of the servers to which you want to apply the defense rule.
        """
        return pulumi.get(self, "uuid_lists")

    @uuid_lists.setter
    def uuid_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "uuid_lists", value)


@pulumi.type_token("alicloud:threatdetection/antiBruteForceRule:AntiBruteForceRule")
class AntiBruteForceRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anti_brute_force_rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 default_rule: Optional[pulumi.Input[builtins.bool]] = None,
                 fail_count: Optional[pulumi.Input[builtins.int]] = None,
                 forbidden_time: Optional[pulumi.Input[builtins.int]] = None,
                 span: Optional[pulumi.Input[builtins.int]] = None,
                 uuid_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a Threat Detection Anti Brute Force Rule resource.

        Anti-brute force cracking rules.

        For information about Threat Detection Anti Brute Force Rule and how to use it, see [What is Anti Brute Force Rule](https://www.alibabacloud.com/help/en/security-center/developer-reference/api-sas-2018-12-03-createantibruteforcerule).

        > **NOTE:** Available since v1.195.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.threatdetection.AntiBruteForceRule("default",
            anti_brute_force_rule_name="apispec_example",
            forbidden_time=360,
            uuid_lists=["032b618f-b220-4a0d-bd37-fbdc6ef58b6a"],
            fail_count=80,
            span=10)
        ```

        ## Import

        Threat Detection Anti Brute Force Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/antiBruteForceRule:AntiBruteForceRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] anti_brute_force_rule_name: The name of the defense rule.
        :param pulumi.Input[builtins.bool] default_rule: Specifies whether to set the defense rule as the default rule. Valid values:
        :param pulumi.Input[builtins.int] fail_count: FailCount
        :param pulumi.Input[builtins.int] forbidden_time: The period of time during which logons from an account are not allowed. Unit: minutes. Valid values:
        :param pulumi.Input[builtins.int] span: The maximum period of time during which failed logon attempts from an account can occur. Unit: minutes. Valid values:
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] uuid_lists: The UUIDs of the servers to which you want to apply the defense rule.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AntiBruteForceRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Threat Detection Anti Brute Force Rule resource.

        Anti-brute force cracking rules.

        For information about Threat Detection Anti Brute Force Rule and how to use it, see [What is Anti Brute Force Rule](https://www.alibabacloud.com/help/en/security-center/developer-reference/api-sas-2018-12-03-createantibruteforcerule).

        > **NOTE:** Available since v1.195.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.threatdetection.AntiBruteForceRule("default",
            anti_brute_force_rule_name="apispec_example",
            forbidden_time=360,
            uuid_lists=["032b618f-b220-4a0d-bd37-fbdc6ef58b6a"],
            fail_count=80,
            span=10)
        ```

        ## Import

        Threat Detection Anti Brute Force Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/antiBruteForceRule:AntiBruteForceRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AntiBruteForceRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AntiBruteForceRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anti_brute_force_rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 default_rule: Optional[pulumi.Input[builtins.bool]] = None,
                 fail_count: Optional[pulumi.Input[builtins.int]] = None,
                 forbidden_time: Optional[pulumi.Input[builtins.int]] = None,
                 span: Optional[pulumi.Input[builtins.int]] = None,
                 uuid_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AntiBruteForceRuleArgs.__new__(AntiBruteForceRuleArgs)

            if anti_brute_force_rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'anti_brute_force_rule_name'")
            __props__.__dict__["anti_brute_force_rule_name"] = anti_brute_force_rule_name
            __props__.__dict__["default_rule"] = default_rule
            if fail_count is None and not opts.urn:
                raise TypeError("Missing required property 'fail_count'")
            __props__.__dict__["fail_count"] = fail_count
            if forbidden_time is None and not opts.urn:
                raise TypeError("Missing required property 'forbidden_time'")
            __props__.__dict__["forbidden_time"] = forbidden_time
            if span is None and not opts.urn:
                raise TypeError("Missing required property 'span'")
            __props__.__dict__["span"] = span
            if uuid_lists is None and not opts.urn:
                raise TypeError("Missing required property 'uuid_lists'")
            __props__.__dict__["uuid_lists"] = uuid_lists
        super(AntiBruteForceRule, __self__).__init__(
            'alicloud:threatdetection/antiBruteForceRule:AntiBruteForceRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            anti_brute_force_rule_name: Optional[pulumi.Input[builtins.str]] = None,
            default_rule: Optional[pulumi.Input[builtins.bool]] = None,
            fail_count: Optional[pulumi.Input[builtins.int]] = None,
            forbidden_time: Optional[pulumi.Input[builtins.int]] = None,
            span: Optional[pulumi.Input[builtins.int]] = None,
            uuid_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'AntiBruteForceRule':
        """
        Get an existing AntiBruteForceRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] anti_brute_force_rule_name: The name of the defense rule.
        :param pulumi.Input[builtins.bool] default_rule: Specifies whether to set the defense rule as the default rule. Valid values:
        :param pulumi.Input[builtins.int] fail_count: FailCount
        :param pulumi.Input[builtins.int] forbidden_time: The period of time during which logons from an account are not allowed. Unit: minutes. Valid values:
        :param pulumi.Input[builtins.int] span: The maximum period of time during which failed logon attempts from an account can occur. Unit: minutes. Valid values:
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] uuid_lists: The UUIDs of the servers to which you want to apply the defense rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AntiBruteForceRuleState.__new__(_AntiBruteForceRuleState)

        __props__.__dict__["anti_brute_force_rule_name"] = anti_brute_force_rule_name
        __props__.__dict__["default_rule"] = default_rule
        __props__.__dict__["fail_count"] = fail_count
        __props__.__dict__["forbidden_time"] = forbidden_time
        __props__.__dict__["span"] = span
        __props__.__dict__["uuid_lists"] = uuid_lists
        return AntiBruteForceRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="antiBruteForceRuleName")
    def anti_brute_force_rule_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the defense rule.
        """
        return pulumi.get(self, "anti_brute_force_rule_name")

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether to set the defense rule as the default rule. Valid values:
        """
        return pulumi.get(self, "default_rule")

    @property
    @pulumi.getter(name="failCount")
    def fail_count(self) -> pulumi.Output[builtins.int]:
        """
        FailCount
        """
        return pulumi.get(self, "fail_count")

    @property
    @pulumi.getter(name="forbiddenTime")
    def forbidden_time(self) -> pulumi.Output[builtins.int]:
        """
        The period of time during which logons from an account are not allowed. Unit: minutes. Valid values:
        """
        return pulumi.get(self, "forbidden_time")

    @property
    @pulumi.getter
    def span(self) -> pulumi.Output[builtins.int]:
        """
        The maximum period of time during which failed logon attempts from an account can occur. Unit: minutes. Valid values:
        """
        return pulumi.get(self, "span")

    @property
    @pulumi.getter(name="uuidLists")
    def uuid_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        The UUIDs of the servers to which you want to apply the defense rule.
        """
        return pulumi.get(self, "uuid_lists")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPricesPriceResult',
    'GetPricesPriceModuleDetailResult',
    'GetPricesPricePromotionDetailResult',
    'GetProductsProductResult',
    'GetResourceTypesTypeResult',
    'GetResourceTypesTypeHandlersResult',
    'GetResourceTypesTypeHandlersCreateResult',
    'GetResourceTypesTypeHandlersDeleteResult',
    'GetResourceTypesTypeHandlersGetResult',
    'GetResourceTypesTypeHandlersListResult',
    'GetResourceTypesTypeHandlersUpdateResult',
    'GetResourceTypesTypeInfoResult',
]

@pulumi.output_type
class GetPricesPriceResult(dict):
    def __init__(__self__, *,
                 currency: builtins.str,
                 discount_price: builtins.float,
                 module_details: Sequence['outputs.GetPricesPriceModuleDetailResult'],
                 original_price: builtins.float,
                 promotion_details: Sequence['outputs.GetPricesPricePromotionDetailResult'],
                 trade_price: builtins.float):
        """
        :param builtins.str currency: Currency. Value range: CNY: RMB. USD: USD. JPY: Japanese yen.
        :param builtins.float discount_price: Discount
        :param Sequence['GetPricesPriceModuleDetailArgs'] module_details: Pricing Module Price Details
        :param builtins.float original_price: Original Price
        :param Sequence['GetPricesPricePromotionDetailArgs'] promotion_details: Offer Details
        :param builtins.float trade_price: Preferential price
        """
        pulumi.set(__self__, "currency", currency)
        pulumi.set(__self__, "discount_price", discount_price)
        pulumi.set(__self__, "module_details", module_details)
        pulumi.set(__self__, "original_price", original_price)
        pulumi.set(__self__, "promotion_details", promotion_details)
        pulumi.set(__self__, "trade_price", trade_price)

    @property
    @pulumi.getter
    def currency(self) -> builtins.str:
        """
        Currency. Value range: CNY: RMB. USD: USD. JPY: Japanese yen.
        """
        return pulumi.get(self, "currency")

    @property
    @pulumi.getter(name="discountPrice")
    def discount_price(self) -> builtins.float:
        """
        Discount
        """
        return pulumi.get(self, "discount_price")

    @property
    @pulumi.getter(name="moduleDetails")
    def module_details(self) -> Sequence['outputs.GetPricesPriceModuleDetailResult']:
        """
        Pricing Module Price Details
        """
        return pulumi.get(self, "module_details")

    @property
    @pulumi.getter(name="originalPrice")
    def original_price(self) -> builtins.float:
        """
        Original Price
        """
        return pulumi.get(self, "original_price")

    @property
    @pulumi.getter(name="promotionDetails")
    def promotion_details(self) -> Sequence['outputs.GetPricesPricePromotionDetailResult']:
        """
        Offer Details
        """
        return pulumi.get(self, "promotion_details")

    @property
    @pulumi.getter(name="tradePrice")
    def trade_price(self) -> builtins.float:
        """
        Preferential price
        """
        return pulumi.get(self, "trade_price")


@pulumi.output_type
class GetPricesPriceModuleDetailResult(dict):
    def __init__(__self__, *,
                 cost_after_discount: builtins.float,
                 invoice_discount: builtins.float,
                 module_code: builtins.str,
                 module_name: builtins.str,
                 original_cost: builtins.float,
                 price_type: builtins.str):
        """
        :param builtins.float cost_after_discount: Preferential price.
        :param builtins.float invoice_discount: Discount.
        :param builtins.str module_code: Valuation Module Identification.
        :param builtins.str module_name: Pricing Module Name.
        :param builtins.float original_cost: Original Price.
        :param builtins.str price_type: Price Type.
        """
        pulumi.set(__self__, "cost_after_discount", cost_after_discount)
        pulumi.set(__self__, "invoice_discount", invoice_discount)
        pulumi.set(__self__, "module_code", module_code)
        pulumi.set(__self__, "module_name", module_name)
        pulumi.set(__self__, "original_cost", original_cost)
        pulumi.set(__self__, "price_type", price_type)

    @property
    @pulumi.getter(name="costAfterDiscount")
    def cost_after_discount(self) -> builtins.float:
        """
        Preferential price.
        """
        return pulumi.get(self, "cost_after_discount")

    @property
    @pulumi.getter(name="invoiceDiscount")
    def invoice_discount(self) -> builtins.float:
        """
        Discount.
        """
        return pulumi.get(self, "invoice_discount")

    @property
    @pulumi.getter(name="moduleCode")
    def module_code(self) -> builtins.str:
        """
        Valuation Module Identification.
        """
        return pulumi.get(self, "module_code")

    @property
    @pulumi.getter(name="moduleName")
    def module_name(self) -> builtins.str:
        """
        Pricing Module Name.
        """
        return pulumi.get(self, "module_name")

    @property
    @pulumi.getter(name="originalCost")
    def original_cost(self) -> builtins.float:
        """
        Original Price.
        """
        return pulumi.get(self, "original_cost")

    @property
    @pulumi.getter(name="priceType")
    def price_type(self) -> builtins.str:
        """
        Price Type.
        """
        return pulumi.get(self, "price_type")


@pulumi.output_type
class GetPricesPricePromotionDetailResult(dict):
    def __init__(__self__, *,
                 promotion_desc: builtins.str,
                 promotion_id: builtins.int,
                 promotion_name: builtins.str):
        """
        :param builtins.str promotion_desc: Offer Description.
        :param builtins.int promotion_id: Offer logo.
        :param builtins.str promotion_name: Offer Name.
        """
        pulumi.set(__self__, "promotion_desc", promotion_desc)
        pulumi.set(__self__, "promotion_id", promotion_id)
        pulumi.set(__self__, "promotion_name", promotion_name)

    @property
    @pulumi.getter(name="promotionDesc")
    def promotion_desc(self) -> builtins.str:
        """
        Offer Description.
        """
        return pulumi.get(self, "promotion_desc")

    @property
    @pulumi.getter(name="promotionId")
    def promotion_id(self) -> builtins.int:
        """
        Offer logo.
        """
        return pulumi.get(self, "promotion_id")

    @property
    @pulumi.getter(name="promotionName")
    def promotion_name(self) -> builtins.str:
        """
        Offer Name.
        """
        return pulumi.get(self, "promotion_name")


@pulumi.output_type
class GetProductsProductResult(dict):
    def __init__(__self__, *,
                 id: builtins.str,
                 product_code: builtins.str,
                 product_name: builtins.str):
        """
        :param builtins.str id: The ID of the resource supplied above.
        :param builtins.str product_code: The first ID of the resource
        :param builtins.str product_name: The name of the resource
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "product_code", product_code)
        pulumi.set(__self__, "product_name", product_name)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the resource supplied above.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> builtins.str:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "product_code")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> builtins.str:
        """
        The name of the resource
        """
        return pulumi.get(self, "product_name")


@pulumi.output_type
class GetResourceTypesTypeResult(dict):
    def __init__(__self__, *,
                 create_only_properties: Sequence[builtins.str],
                 delete_only_properties: Sequence[builtins.str],
                 filter_properties: Sequence[builtins.str],
                 get_only_properties: Sequence[builtins.str],
                 get_response_properties: Sequence[builtins.str],
                 handlers: 'outputs.GetResourceTypesTypeHandlersResult',
                 id: builtins.str,
                 infos: Sequence['outputs.GetResourceTypesTypeInfoResult'],
                 list_only_properties: Sequence[builtins.str],
                 list_response_properties: Sequence[builtins.str],
                 primary_identifier: builtins.str,
                 product: builtins.str,
                 properties: builtins.str,
                 public_properties: Sequence[builtins.str],
                 read_only_properties: Sequence[builtins.str],
                 requireds: Sequence[builtins.str],
                 resource_type: builtins.str,
                 sensitive_info_properties: Sequence[builtins.str],
                 update_only_properties: Sequence[builtins.str],
                 update_type_properties: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] create_only_properties: Create an operation private parameter collection. The attributes are not returned in the resource query operation, but the parameters are required in the creation operation.
        :param Sequence[builtins.str] delete_only_properties: Delete operation private parameter collection. The attribute is not returned in the resource query operation, but the parameter is required in the delete operation.
        :param Sequence[builtins.str] filter_properties: A collection of attributes that can be used as the filter parameter during the list operation.
        :param Sequence[builtins.str] get_only_properties: Query operation private parameter collection. The attribute is not returned in the resource query operation, but the input parameter is required in the query operation.
        :param Sequence[builtins.str] get_response_properties: The collection of properties returned by the query.
        :param 'GetResourceTypesTypeHandlersArgs' handlers: Supported resource operation information (including RAM permissions).
        :param builtins.str id: The ID of the resource supplied above.
        :param Sequence['GetResourceTypesTypeInfoArgs'] infos: Basic information about the resource type.
        :param Sequence[builtins.str] list_only_properties: Enumerate the operation private parameter collection. The attributes are not returned in the resource query operation, but the parameters that need to be passed in the enumeration operation.
        :param Sequence[builtins.str] list_response_properties: Enumerates the returned property collection.
        :param builtins.str primary_identifier: Resource ID
        :param builtins.str product: Product Code.
        :param builtins.str properties: Resource attribute definition, where key is the attribute name and value is the attribute details.
        :param Sequence[builtins.str] public_properties: A collection of public attributes, which are the basic attributes of the resource. Non-Operation private parameters.
        :param Sequence[builtins.str] read_only_properties: A set of read-only parameters. It is returned only in the list or get Operation. It is not used as an input parameter during creation and change.
        :param Sequence[builtins.str] requireds: Resource creation required parameter collection.
        :param builtins.str resource_type: The resource type.
        :param Sequence[builtins.str] sensitive_info_properties: A collection of sensitive attributes, such as passwords.
        :param Sequence[builtins.str] update_only_properties: Update operation private parameter collection. The attributes are not returned in the resource query operation, but the parameters are required in the update operation.
        :param Sequence[builtins.str] update_type_properties: A collection of properties that can be modified.
        """
        pulumi.set(__self__, "create_only_properties", create_only_properties)
        pulumi.set(__self__, "delete_only_properties", delete_only_properties)
        pulumi.set(__self__, "filter_properties", filter_properties)
        pulumi.set(__self__, "get_only_properties", get_only_properties)
        pulumi.set(__self__, "get_response_properties", get_response_properties)
        pulumi.set(__self__, "handlers", handlers)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "infos", infos)
        pulumi.set(__self__, "list_only_properties", list_only_properties)
        pulumi.set(__self__, "list_response_properties", list_response_properties)
        pulumi.set(__self__, "primary_identifier", primary_identifier)
        pulumi.set(__self__, "product", product)
        pulumi.set(__self__, "properties", properties)
        pulumi.set(__self__, "public_properties", public_properties)
        pulumi.set(__self__, "read_only_properties", read_only_properties)
        pulumi.set(__self__, "requireds", requireds)
        pulumi.set(__self__, "resource_type", resource_type)
        pulumi.set(__self__, "sensitive_info_properties", sensitive_info_properties)
        pulumi.set(__self__, "update_only_properties", update_only_properties)
        pulumi.set(__self__, "update_type_properties", update_type_properties)

    @property
    @pulumi.getter(name="createOnlyProperties")
    def create_only_properties(self) -> Sequence[builtins.str]:
        """
        Create an operation private parameter collection. The attributes are not returned in the resource query operation, but the parameters are required in the creation operation.
        """
        return pulumi.get(self, "create_only_properties")

    @property
    @pulumi.getter(name="deleteOnlyProperties")
    def delete_only_properties(self) -> Sequence[builtins.str]:
        """
        Delete operation private parameter collection. The attribute is not returned in the resource query operation, but the parameter is required in the delete operation.
        """
        return pulumi.get(self, "delete_only_properties")

    @property
    @pulumi.getter(name="filterProperties")
    def filter_properties(self) -> Sequence[builtins.str]:
        """
        A collection of attributes that can be used as the filter parameter during the list operation.
        """
        return pulumi.get(self, "filter_properties")

    @property
    @pulumi.getter(name="getOnlyProperties")
    def get_only_properties(self) -> Sequence[builtins.str]:
        """
        Query operation private parameter collection. The attribute is not returned in the resource query operation, but the input parameter is required in the query operation.
        """
        return pulumi.get(self, "get_only_properties")

    @property
    @pulumi.getter(name="getResponseProperties")
    def get_response_properties(self) -> Sequence[builtins.str]:
        """
        The collection of properties returned by the query.
        """
        return pulumi.get(self, "get_response_properties")

    @property
    @pulumi.getter
    def handlers(self) -> 'outputs.GetResourceTypesTypeHandlersResult':
        """
        Supported resource operation information (including RAM permissions).
        """
        return pulumi.get(self, "handlers")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the resource supplied above.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def infos(self) -> Sequence['outputs.GetResourceTypesTypeInfoResult']:
        """
        Basic information about the resource type.
        """
        return pulumi.get(self, "infos")

    @property
    @pulumi.getter(name="listOnlyProperties")
    def list_only_properties(self) -> Sequence[builtins.str]:
        """
        Enumerate the operation private parameter collection. The attributes are not returned in the resource query operation, but the parameters that need to be passed in the enumeration operation.
        """
        return pulumi.get(self, "list_only_properties")

    @property
    @pulumi.getter(name="listResponseProperties")
    def list_response_properties(self) -> Sequence[builtins.str]:
        """
        Enumerates the returned property collection.
        """
        return pulumi.get(self, "list_response_properties")

    @property
    @pulumi.getter(name="primaryIdentifier")
    def primary_identifier(self) -> builtins.str:
        """
        Resource ID
        """
        return pulumi.get(self, "primary_identifier")

    @property
    @pulumi.getter
    def product(self) -> builtins.str:
        """
        Product Code.
        """
        return pulumi.get(self, "product")

    @property
    @pulumi.getter
    def properties(self) -> builtins.str:
        """
        Resource attribute definition, where key is the attribute name and value is the attribute details.
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter(name="publicProperties")
    def public_properties(self) -> Sequence[builtins.str]:
        """
        A collection of public attributes, which are the basic attributes of the resource. Non-Operation private parameters.
        """
        return pulumi.get(self, "public_properties")

    @property
    @pulumi.getter(name="readOnlyProperties")
    def read_only_properties(self) -> Sequence[builtins.str]:
        """
        A set of read-only parameters. It is returned only in the list or get Operation. It is not used as an input parameter during creation and change.
        """
        return pulumi.get(self, "read_only_properties")

    @property
    @pulumi.getter
    def requireds(self) -> Sequence[builtins.str]:
        """
        Resource creation required parameter collection.
        """
        return pulumi.get(self, "requireds")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> builtins.str:
        """
        The resource type.
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="sensitiveInfoProperties")
    def sensitive_info_properties(self) -> Sequence[builtins.str]:
        """
        A collection of sensitive attributes, such as passwords.
        """
        return pulumi.get(self, "sensitive_info_properties")

    @property
    @pulumi.getter(name="updateOnlyProperties")
    def update_only_properties(self) -> Sequence[builtins.str]:
        """
        Update operation private parameter collection. The attributes are not returned in the resource query operation, but the parameters are required in the update operation.
        """
        return pulumi.get(self, "update_only_properties")

    @property
    @pulumi.getter(name="updateTypeProperties")
    def update_type_properties(self) -> Sequence[builtins.str]:
        """
        A collection of properties that can be modified.
        """
        return pulumi.get(self, "update_type_properties")


@pulumi.output_type
class GetResourceTypesTypeHandlersResult(dict):
    def __init__(__self__, *,
                 creates: Sequence['outputs.GetResourceTypesTypeHandlersCreateResult'],
                 deletes: Sequence['outputs.GetResourceTypesTypeHandlersDeleteResult'],
                 gets: Sequence['outputs.GetResourceTypesTypeHandlersGetResult'],
                 lists: Sequence['outputs.GetResourceTypesTypeHandlersListResult'],
                 updates: Sequence['outputs.GetResourceTypesTypeHandlersUpdateResult']):
        """
        :param Sequence['GetResourceTypesTypeHandlersCreateArgs'] creates: Create operation association information.
        :param Sequence['GetResourceTypesTypeHandlersDeleteArgs'] deletes: Delete operation association information.
        :param Sequence['GetResourceTypesTypeHandlersGetArgs'] gets: Query operation association information.
        :param Sequence['GetResourceTypesTypeHandlersListArgs'] lists: List operation association information.
        :param Sequence['GetResourceTypesTypeHandlersUpdateArgs'] updates: Update operation association information.
        """
        pulumi.set(__self__, "creates", creates)
        pulumi.set(__self__, "deletes", deletes)
        pulumi.set(__self__, "gets", gets)
        pulumi.set(__self__, "lists", lists)
        pulumi.set(__self__, "updates", updates)

    @property
    @pulumi.getter
    def creates(self) -> Sequence['outputs.GetResourceTypesTypeHandlersCreateResult']:
        """
        Create operation association information.
        """
        return pulumi.get(self, "creates")

    @property
    @pulumi.getter
    def deletes(self) -> Sequence['outputs.GetResourceTypesTypeHandlersDeleteResult']:
        """
        Delete operation association information.
        """
        return pulumi.get(self, "deletes")

    @property
    @pulumi.getter
    def gets(self) -> Sequence['outputs.GetResourceTypesTypeHandlersGetResult']:
        """
        Query operation association information.
        """
        return pulumi.get(self, "gets")

    @property
    @pulumi.getter
    def lists(self) -> Sequence['outputs.GetResourceTypesTypeHandlersListResult']:
        """
        List operation association information.
        """
        return pulumi.get(self, "lists")

    @property
    @pulumi.getter
    def updates(self) -> Sequence['outputs.GetResourceTypesTypeHandlersUpdateResult']:
        """
        Update operation association information.
        """
        return pulumi.get(self, "updates")


@pulumi.output_type
class GetResourceTypesTypeHandlersCreateResult(dict):
    def __init__(__self__, *,
                 permissions: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] permissions: The collection of required RAM permission information.
        """
        pulumi.set(__self__, "permissions", permissions)

    @property
    @pulumi.getter
    def permissions(self) -> Sequence[builtins.str]:
        """
        The collection of required RAM permission information.
        """
        return pulumi.get(self, "permissions")


@pulumi.output_type
class GetResourceTypesTypeHandlersDeleteResult(dict):
    def __init__(__self__, *,
                 permissions: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] permissions: The collection of required RAM permission information.
        """
        pulumi.set(__self__, "permissions", permissions)

    @property
    @pulumi.getter
    def permissions(self) -> Sequence[builtins.str]:
        """
        The collection of required RAM permission information.
        """
        return pulumi.get(self, "permissions")


@pulumi.output_type
class GetResourceTypesTypeHandlersGetResult(dict):
    def __init__(__self__, *,
                 permissions: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] permissions: The collection of required RAM permission information.
        """
        pulumi.set(__self__, "permissions", permissions)

    @property
    @pulumi.getter
    def permissions(self) -> Sequence[builtins.str]:
        """
        The collection of required RAM permission information.
        """
        return pulumi.get(self, "permissions")


@pulumi.output_type
class GetResourceTypesTypeHandlersListResult(dict):
    def __init__(__self__, *,
                 permissions: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] permissions: The collection of required RAM permission information.
        """
        pulumi.set(__self__, "permissions", permissions)

    @property
    @pulumi.getter
    def permissions(self) -> Sequence[builtins.str]:
        """
        The collection of required RAM permission information.
        """
        return pulumi.get(self, "permissions")


@pulumi.output_type
class GetResourceTypesTypeHandlersUpdateResult(dict):
    def __init__(__self__, *,
                 permissions: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] permissions: The collection of required RAM permission information.
        """
        pulumi.set(__self__, "permissions", permissions)

    @property
    @pulumi.getter
    def permissions(self) -> Sequence[builtins.str]:
        """
        The collection of required RAM permission information.
        """
        return pulumi.get(self, "permissions")


@pulumi.output_type
class GetResourceTypesTypeInfoResult(dict):
    def __init__(__self__, *,
                 charge_type: builtins.str,
                 delivery_scope: builtins.str,
                 description: builtins.str,
                 title: builtins.str):
        """
        :param builtins.str charge_type: Payment formpaid (paid)(free).
        :param builtins.str delivery_scope: Delivery Levelcenter (centralized deployment level)region (regional deployment level)zone (Availability zone deployment level).
        :param builtins.str description: Resource type description.
        :param builtins.str title: The resource type name.
        """
        pulumi.set(__self__, "charge_type", charge_type)
        pulumi.set(__self__, "delivery_scope", delivery_scope)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        Payment formpaid (paid)(free).
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="deliveryScope")
    def delivery_scope(self) -> builtins.str:
        """
        Delivery Levelcenter (centralized deployment level)region (regional deployment level)zone (Availability zone deployment level).
        """
        return pulumi.get(self, "delivery_scope")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Resource type description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def title(self) -> builtins.str:
        """
        The resource type name.
        """
        return pulumi.get(self, "title")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .alias import *
from .custom_domain import *
from .function import *
from .function_async_invoke_config import *
from .get_custom_domains import *
from .get_functions import *
from .get_service import *
from .get_services import *
from .get_triggers import *
from .get_v3_triggers import *
from .get_zones import *
from .layer_version import *
from .service import *
from .trigger import *
from .v2_function import *
from .v3_alias import *
from .v3_async_invoke_config import *
from .v3_concurrency_config import *
from .v3_custom_domain import *
from .v3_function import *
from .v3_function_version import *
from .v3_layer_version import *
from .v3_provision_config import *
from .v3_trigger import *
from .v3_vpc_binding import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRolePolicyAttachmentsResult',
    'AwaitableGetRolePolicyAttachmentsResult',
    'get_role_policy_attachments',
    'get_role_policy_attachments_output',
]

@pulumi.output_type
class GetRolePolicyAttachmentsResult:
    """
    A collection of values returned by getRolePolicyAttachments.
    """
    def __init__(__self__, attachments=None, id=None, ids=None, output_file=None, role_name=None):
        if attachments and not isinstance(attachments, list):
            raise TypeError("Expected argument 'attachments' to be a list")
        pulumi.set(__self__, "attachments", attachments)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if role_name and not isinstance(role_name, str):
            raise TypeError("Expected argument 'role_name' to be a str")
        pulumi.set(__self__, "role_name", role_name)

    @property
    @pulumi.getter
    def attachments(self) -> Sequence['outputs.GetRolePolicyAttachmentsAttachmentResult']:
        """
        A list of Role Policy Attachment Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "attachments")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Role Policy Attachment IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> builtins.str:
        return pulumi.get(self, "role_name")


class AwaitableGetRolePolicyAttachmentsResult(GetRolePolicyAttachmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRolePolicyAttachmentsResult(
            attachments=self.attachments,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            role_name=self.role_name)


def get_role_policy_attachments(ids: Optional[Sequence[builtins.str]] = None,
                                output_file: Optional[builtins.str] = None,
                                role_name: Optional[builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRolePolicyAttachmentsResult:
    """
    This data source provides Ram Role Policy Attachment available to the user.[What is Role Policy Attachment](https://next.api.alibabacloud.com/document/Ram/2015-05-01/AttachPolicyToRole)

    > **NOTE:** Available since v1.248.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    role = alicloud.ram.Role("role",
        name="roleName",
        document=\"\"\"    {
          "Statement": [
            {
              "Action": "sts:AssumeRole",
              "Effect": "Allow",
              "Principal": {
                "Service": [
                  "apigateway.aliyuncs.com", 
                  "ecs.aliyuncs.com"
                ]
              }
            }
          ],
          "Version": "1"
        }
    \"\"\",
        description="this is a role test.")
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    policy = alicloud.ram.Policy("policy",
        policy_name=f"tf-example-{default_integer['result']}",
        policy_document=\"\"\"  {
        "Statement": [
          {
            "Action": [
              "oss:ListObjects",
              "oss:GetObject"
            ],
            "Effect": "Allow",
            "Resource": [
              "acs:oss:*:*:mybucket",
              "acs:oss:*:*:mybucket/*"
            ]
          }
        ],
          "Version": "1"
      }
    \"\"\",
        description="this is a policy test")
    default_role_policy_attachment = alicloud.ram.RolePolicyAttachment("default",
        policy_name=policy.policy_name,
        policy_type=policy.type,
        role_name=role.name)
    default = alicloud.ram.get_role_policy_attachments_output(ids=[default_role_policy_attachment.id],
        role_name=role.id)
    pulumi.export("alicloudRamRolePolicyAttachmentExampleId", default.attachments[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Role Policy Attachment IDs. The value is formulated as `role:<policy_name>:<policy_type>:<role_name>`.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str role_name: The RAM role name.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['roleName'] = role_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ram/getRolePolicyAttachments:getRolePolicyAttachments', __args__, opts=opts, typ=GetRolePolicyAttachmentsResult).value

    return AwaitableGetRolePolicyAttachmentsResult(
        attachments=pulumi.get(__ret__, 'attachments'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        role_name=pulumi.get(__ret__, 'role_name'))
def get_role_policy_attachments_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                       output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       role_name: Optional[pulumi.Input[builtins.str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRolePolicyAttachmentsResult]:
    """
    This data source provides Ram Role Policy Attachment available to the user.[What is Role Policy Attachment](https://next.api.alibabacloud.com/document/Ram/2015-05-01/AttachPolicyToRole)

    > **NOTE:** Available since v1.248.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    role = alicloud.ram.Role("role",
        name="roleName",
        document=\"\"\"    {
          "Statement": [
            {
              "Action": "sts:AssumeRole",
              "Effect": "Allow",
              "Principal": {
                "Service": [
                  "apigateway.aliyuncs.com", 
                  "ecs.aliyuncs.com"
                ]
              }
            }
          ],
          "Version": "1"
        }
    \"\"\",
        description="this is a role test.")
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    policy = alicloud.ram.Policy("policy",
        policy_name=f"tf-example-{default_integer['result']}",
        policy_document=\"\"\"  {
        "Statement": [
          {
            "Action": [
              "oss:ListObjects",
              "oss:GetObject"
            ],
            "Effect": "Allow",
            "Resource": [
              "acs:oss:*:*:mybucket",
              "acs:oss:*:*:mybucket/*"
            ]
          }
        ],
          "Version": "1"
      }
    \"\"\",
        description="this is a policy test")
    default_role_policy_attachment = alicloud.ram.RolePolicyAttachment("default",
        policy_name=policy.policy_name,
        policy_type=policy.type,
        role_name=role.name)
    default = alicloud.ram.get_role_policy_attachments_output(ids=[default_role_policy_attachment.id],
        role_name=role.id)
    pulumi.export("alicloudRamRolePolicyAttachmentExampleId", default.attachments[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Role Policy Attachment IDs. The value is formulated as `role:<policy_name>:<policy_type>:<role_name>`.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str role_name: The RAM role name.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['roleName'] = role_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ram/getRolePolicyAttachments:getRolePolicyAttachments', __args__, opts=opts, typ=GetRolePolicyAttachmentsResult)
    return __ret__.apply(lambda __response__: GetRolePolicyAttachmentsResult(
        attachments=pulumi.get(__response__, 'attachments'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        role_name=pulumi.get(__response__, 'role_name')))
